# /polysquarelinter/technical_words_dictionary.py
#
# Helper module to create caches and a Dictionary for technical
# words.
#
# See /LICENCE.md for Copyright information
"""Helper module to populate caches for technical words."""

import os

from polysquarelinter.spelling import (Dictionary,
                                       read_dictionary_file)


def create(technical_terms_filename, spellchecker_cache_path):
    """Create a Dictionary at spellchecker_cache_path with technical words."""
    user_dictionary = os.path.join(os.getcwd(), "DICTIONARY")
    user_words = read_dictionary_file(user_dictionary)

    technical_terms_set = set(user_words)

    if technical_terms_filename:
        with open(technical_terms_filename) as tech_tf:
            technical_terms_set |= set(tech_tf.read().splitlines())

    return Dictionary(technical_terms_set,
                      "technical_words",
                      dictionary_sources=[technical_terms_filename,
                                          user_dictionary],
                      cache=spellchecker_cache_path)



# /polysquarelinter/valid_words_dictionary.py
#
# Helper module to create caches and a Dictionary for regular english words
# and any user defined words.
#
# See /LICENCE.md for Copyright information
"""Helper module to create caches for ordinary and user defined words."""

import os

from polysquarelinter.spelling import (Dictionary,
                                       read_dictionary_file,
                                       valid_words_set)


def create(spellchecker_cache_path):
    """Create a Dictionary at spellchecker_cache_path with valid words."""
    user_dictionary = os.path.join(os.getcwd(), "DICTIONARY")
    user_words = read_dictionary_file(user_dictionary)

    valid_words = Dictionary(valid_words_set(user_dictionary, user_words),
                             "valid_words",
                             [user_dictionary],
                             spellchecker_cache_path)

    return (user_words, valid_words)



# /polysquarelinter/cache_populate.py
#
# Populate caches before running multiple checker processes in parallel.
#
# See /LICENCE.md for Copyright information
"""Populate caches before running multiple checker processes in parallel."""

import argparse

import sys

from polysquarelinter import (technical_words_dictionary,
                              valid_words_dictionary)


def main():  # suppress(unused-function)
    """Cause the cache to be populated with valid words."""
    description = ("""Pre-populate cache for polysquare-generic-file-linter """
                   """and spellcheck-linter.""")
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument("cache_path",
                        metavar=("PATH"),
                        help="""PATH to cache""",
                        type=str)
    parser.add_argument("--technical-terms",
                        metavar=("FILE"),
                        help="""FILE containing technical terms""",
                        type=str)
    arguments = parser.parse_args(sys.argv[1:])
    valid_words_dictionary.create(arguments.cache_path)
    technical_words_dictionary.create(arguments.technical_terms,
                                      arguments.cache_path)
    return 0
